@@ -145,15 +145,6 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             d[typename] = sub
         return d
 
-    @classmethod
-    def from_gql_query_str(
-        cls: ResolverType, gql_str: str, path: T.List[str]
-    ) -> ResolverType:
-        """ find the nested and use that """
-        """{name age is_friends_with {name}}"""
-        edge_names = cls.edges.__fields__.keys()
-        ...
-
     """
     def get(self, get_params: GetParamsType) -> T.Optional[NodeType]:
         return self._get(kwargs_d=get_params.dict())
